@@ -8,8 +8,8 @@ He X, Liao L, Zhang H, et al. Neural collaborative filtering[C]//Proceedings of
 
 import math
 
-from deepctr.inputs import input_from_feature_columns, build_input_features, combined_dnn_input, SparseFeat
-from deepctr.layers.core import DNN
+from deepctr.feature_column import input_from_feature_columns, build_input_features, SparseFeat
+from deepctr.layers import DNN, combined_dnn_input
 from tensorflow.python.keras.layers import Lambda, Concatenate, Multiply
 from tensorflow.python.keras.models import Model
 
@@ -17,7 +17,7 @@ from tensorflow.python.keras.models import Model
 def NCF(user_feature_columns, item_feature_columns, user_gmf_embedding_dim=20, item_gmf_embedding_dim=20,
         user_mlp_embedding_dim=20, item_mlp_embedding_dim=20, dnn_use_bn=False,
         dnn_hidden_units=(64, 32), dnn_activation='relu', l2_reg_dnn=0, l2_reg_embedding=1e-6, dnn_dropout=0,
-        init_std=0.0001, seed=1024):
+        seed=1024):
     """Instantiates the NCF Model architecture.
 
     :param user_feature_columns: A dict containing user's features and features'dim.
@@ -32,7 +32,6 @@ def NCF(user_feature_columns, item_feature_columns, user_gmf_embedding_dim=20, i
     :param l2_reg_dnn: float. L2 regularizer strength applied to DNN
     :param l2_reg_embedding: float. L2 regularizer strength applied to embedding vector
     :param dnn_dropout: float in [0,1), the probability we will drop out a given DNN coordinate.
-    :param init_std: float,to use as the initialize std of embedding vector
     :param seed: integer ,to use as random seed.
     :return: A Keras model instance.
 
@@ -51,8 +50,8 @@ def NCF(user_feature_columns, item_feature_columns, user_gmf_embedding_dim=20, i
     user_inputs_list = list(user_features.values())
     user_gmf_sparse_embedding_list, user_gmf_dense_value_list = input_from_feature_columns(user_features,
                                                                                            user_gmf_feature_columns,
-                                                                                           l2_reg_embedding, init_std,
-                                                                                           seed, prefix='gmf_')
+                                                                                           l2_reg_embedding, seed=seed,
+                                                                                           prefix='gmf_')
     user_gmf_input = combined_dnn_input(user_gmf_sparse_embedding_list, [])
     user_gmf_out = Lambda(lambda x: x, name="user_gmf_embedding")(user_gmf_input)
 
@@ -62,8 +61,8 @@ def NCF(user_feature_columns, item_feature_columns, user_gmf_embedding_dim=20, i
     item_inputs_list = list(item_features.values())
     item_gmf_sparse_embedding_list, item_gmf_dense_value_list = input_from_feature_columns(item_features,
                                                                                            item_gmf_feature_columns,
-                                                                                           l2_reg_embedding, init_std,
-                                                                                           seed, prefix='gmf_')
+                                                                                           l2_reg_embedding, seed=seed,
+                                                                                           prefix='gmf_')
     item_gmf_input = combined_dnn_input(item_gmf_sparse_embedding_list, [])
     item_gmf_out = Lambda(lambda x: x, name="item_gmf_embedding")(item_gmf_input)
 
@@ -74,8 +73,8 @@ def NCF(user_feature_columns, item_feature_columns, user_gmf_embedding_dim=20, i
                                 for feat, size in user_feature_columns.items()]
     user_mlp_sparse_embedding_list, user_mlp_dense_value_list = input_from_feature_columns(user_features,
                                                                                            user_mlp_feature_columns,
-                                                                                           l2_reg_embedding, init_std,
-                                                                                           seed, prefix='mlp_')
+                                                                                           l2_reg_embedding, seed=seed,
+                                                                                           prefix='mlp_')
     user_mlp_input = combined_dnn_input(
         user_mlp_sparse_embedding_list, user_mlp_dense_value_list)
     user_mlp_out = Lambda(lambda x: x, name="user_mlp_embedding")(user_mlp_input)
@@ -85,19 +84,19 @@ def NCF(user_feature_columns, item_feature_columns, user_gmf_embedding_dim=20, i
 
     item_mlp_sparse_embedding_list, item_mlp_dense_value_list = input_from_feature_columns(item_features,
                                                                                            item_mlp_feature_columns,
-                                                                                           l2_reg_embedding, init_std,
-                                                                                           seed, prefix='mlp_')
+                                                                                           l2_reg_embedding, seed=seed,
+                                                                                           prefix='mlp_')
     item_mlp_input = combined_dnn_input(
         item_mlp_sparse_embedding_list, item_mlp_dense_value_list)
     item_mlp_out = Lambda(lambda x: x, name="item_mlp_embedding")(item_mlp_input)
 
     mlp_input = Concatenate(axis=1)([user_mlp_out, item_mlp_out])
     mlp_out = DNN(dnn_hidden_units, dnn_activation, l2_reg_dnn, dnn_dropout,
-                  dnn_use_bn, seed, name="mlp_embedding")(mlp_input)
+                  dnn_use_bn, seed = seed, name="mlp_embedding")(mlp_input)
 
     # Fusion of GMF and MLP
     neumf_input = Concatenate(axis=1)([gmf_out, mlp_out])
-    neumf_out = DNN(hidden_units=[1], activation='sigmoid')(neumf_input)
+    neumf_out = DNN(hidden_units=[1], activation='sigmoid',seed=seed)(neumf_input)
     output = Lambda(lambda x: x, name='neumf_out')(neumf_out)
 
     # output = PredictionLayer(task, False)(neumf_out)
