@@ -4,21 +4,21 @@ Author:
 Reference:
 Covington P, Adams J, Sargin E. Deep neural networks for youtube recommendations[C]//Proceedings of the 10th ACM conference on recommender systems. 2016: 191-198.
 """
-from deepctr.inputs import input_from_feature_columns, build_input_features, combined_dnn_input, create_embedding_matrix
-from deepctr.layers.core import DNN
-from deepctr.layers.utils import NoMask
+from deepctr.feature_column import build_input_features
+from deepctr.layers import DNN
+from deepctr.layers.utils import NoMask, combined_dnn_input
 from tensorflow.python.keras.models import Model
 
 from deepmatch.layers import PoolingLayer
 from deepmatch.utils import get_item_embedding
-from ..inputs import input_from_feature_columns
+from ..inputs import input_from_feature_columns, create_embedding_matrix
 from ..layers.core import SampledSoftmaxLayer, EmbeddingIndex
 
 
 def YoutubeDNN(user_feature_columns, item_feature_columns, num_sampled=5,
                user_dnn_hidden_units=(64, 32),
                dnn_activation='relu', dnn_use_bn=False,
-               l2_reg_dnn=0, l2_reg_embedding=1e-6, dnn_dropout=0, init_std=0.0001, seed=1024, ):
+               l2_reg_dnn=0, l2_reg_embedding=1e-6, dnn_dropout=0, output_activation='linear', seed=1024, ):
     """Instantiates the YoutubeDNN Model architecture.
 
     :param user_feature_columns: An iterable containing user's features used by  the model.
@@ -30,8 +30,8 @@ def YoutubeDNN(user_feature_columns, item_feature_columns, num_sampled=5,
     :param l2_reg_dnn: float. L2 regularizer strength applied to DNN
     :param l2_reg_embedding: float. L2 regularizer strength applied to embedding vector
     :param dnn_dropout: float in [0,1), the probability we will drop out a given DNN coordinate.
-    :param init_std: float,to use as the initialize std of embedding vector
     :param seed: integer ,to use as random seed.
+    :param output_activation: Activation function to use in output layer
     :return: A Keras model instance.
 
     """
@@ -42,20 +42,19 @@ def YoutubeDNN(user_feature_columns, item_feature_columns, num_sampled=5,
     item_vocabulary_size = item_feature_columns[0].vocabulary_size
 
     embedding_matrix_dict = create_embedding_matrix(user_feature_columns + item_feature_columns, l2_reg_embedding,
-                                                    init_std, seed, prefix="")
+                                                    seed=seed)
 
     user_features = build_input_features(user_feature_columns)
     user_inputs_list = list(user_features.values())
-    user_sparse_embedding_list, user_dense_value_list = input_from_feature_columns(user_features,
-                                                                                   user_feature_columns,
-                                                                                   l2_reg_embedding, init_std, seed,
+    user_sparse_embedding_list, user_dense_value_list = input_from_feature_columns(user_features, user_feature_columns,
+                                                                                   l2_reg_embedding, seed=seed,
                                                                                    embedding_matrix_dict=embedding_matrix_dict)
     user_dnn_input = combined_dnn_input(user_sparse_embedding_list, user_dense_value_list)
 
     item_features = build_input_features(item_feature_columns)
     item_inputs_list = list(item_features.values())
     user_dnn_out = DNN(user_dnn_hidden_units, dnn_activation, l2_reg_dnn, dnn_dropout,
-                       dnn_use_bn, seed, )(user_dnn_input)
+                       dnn_use_bn, output_activation=output_activation, seed=seed)(user_dnn_input)
 
     item_index = EmbeddingIndex(list(range(item_vocabulary_size)))(item_features[item_feature_name])
 
